bulkdata
========

Subpackages
^^^^^^^^^^^

.. toctree::

    bulkdata.pyNastran

Submodules
^^^^^^^^^^

bulkdata.card
-------------

.. automodule:: bulkdata.card
    :members:
    :undoc-members:
    :special-members: __getitem__, __setitem__, __delitem__, __str__, __len__, __iter__, __bool__

bulkdata.cli
------------

.. automodule:: bulkdata.cli
    :members:
    :undoc-members:

bulkdata.deck
-------------

.. automodule:: bulkdata.deck
    :members:
    :undoc-members:
    :special-members: __getitem__, __setitem__, __str__, __len__, __iter__, __bool__

bulkdata.error
--------------

.. automodule:: bulkdata.error
    :members:
    :undoc-members:

bulkdata.field
--------------

.. automodule:: bulkdata.field
    :members:
    :undoc-members:

bulkdata.format
---------------

.. automodule:: bulkdata.format
    :members:
    :undoc-members:

bulkdata.parse
--------------

.. automodule:: bulkdata.parse
    :members:
    :undoc-members:

bulkdata.util
-------------

.. automodule:: bulkdata.util
    :members:
    :undoc-members:


Module
^^^^^^

.. automodule:: bulkdata
    :members:
    :undoc-members:

The :class:`~bulkdata.card.Card` and :class:`~bulkdata.deck.Deck`
classes are accessible via the top-level :mod:`bulkdata` module.
